### Fast & Simple Time Series DB

#### Installation

`pip3 install pytdb`

Note: this will install the `pytdb_cc` dependency which requires protobuf C++ library 
to be installed and available via `find_package(Protobuf)`. Standard build tools must also be 
installated.

